==> jc-1.4.0.tar.gz: gnu/xml/xpath/XPathParser__24YyCheckClass.h <==
// public final class gnu.xml.xpath.XPathParser$YyCheckClass

// class file dependencies
// @dep_class 4d15a1359e629c72 gnu_xml_xpath_XPathParser__24YyCheckClass
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_xpath_XPathParser__24YyCheckClass_H_
#define _JC_gnu_xml_xpath_XPathParser__24YyCheckClass_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyCheckClass$sub_refs	_jc_gnu_xml_xpath_XPathParser__24YyCheckClass$sub_refs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyCheckClass$sub_nonrefs	_jc_gnu_xml_xpath_XPathParser__24YyCheckClass$sub_nonrefs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyCheckClass$refs	_jc_gnu_xml_xpath_XPathParser__24YyCheckClass$refs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyCheckClass$nonrefs	_jc_gnu_xml_xpath_XPathParser__24YyCheckClass$nonrefs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyCheckClass$object	_jc_gnu_xml_xpath_XPathParser__24YyCheckClass$object;

typedef struct _jc_gnu_xml_xpath_XPathParser__24YyCheckClass$fields_struct	_jc_gnu_xml_xpath_XPathParser__24YyCheckClass$fields_struct;
typedef const struct _jc_gnu_xml_xpath_XPathParser__24YyCheckClass$vmethods	_jc_gnu_xml_xpath_XPathParser__24YyCheckClass$vmethods;
typedef const struct _jc_gnu_xml_xpath_XPathParser__24YyCheckClass$vtable	_jc_gnu_xml_xpath_XPathParser__24YyCheckClass$vtable;
typedef const struct _jc_gnu_xml_xpath_XPathParser__24YyCheckClass$vtype	_jc_gnu_xml_xpath_XPathParser__24YyCheckClass$vtype;

// Class fields structure
struct _jc_gnu_xml_xpath_XPathParser__24YyCheckClass$fields_struct {
	_jc_short_array	*yyCheck;
};
extern _jc_gnu_xml_xpath_XPathParser__24YyCheckClass$fields_struct _jc_gnu_xml_xpath_XPathParser__24YyCheckClass$class_fields;

// Constructors
extern void _jc_gnu_xml_xpath_XPathParser__24YyCheckClass$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_xml_xpath_XPathParser__24YyCheckClass$object *);

// Static methods
extern void _jc_gnu_xml_xpath_XPathParser__24YyCheckClass$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_gnu_xml_xpath_XPathParser__24YyCheckClass$vmethods {
};

// Vtable
struct _jc_gnu_xml_xpath_XPathParser__24YyCheckClass$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_xpath_XPathParser__24YyCheckClass$vmethods	gnu_xml_xpath_XPathParser__24YyCheckClass;
};

// Vtype
struct _jc_gnu_xml_xpath_XPathParser__24YyCheckClass$vtype {
	_jc_type			type;
	_jc_gnu_xml_xpath_XPathParser__24YyCheckClass$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_xpath_XPathParser__24YyCheckClass$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_xpath_XPathParser__24YyCheckClass$refs {
    _jc_gnu_xml_xpath_XPathParser__24YyCheckClass$sub_refs	gnu_xml_xpath_XPathParser__24YyCheckClass;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_xpath_XPathParser__24YyCheckClass$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_xpath_XPathParser__24YyCheckClass$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_xpath_XPathParser__24YyCheckClass$sub_nonrefs	gnu_xml_xpath_XPathParser__24YyCheckClass;
};

// Object instance structure
struct _jc_gnu_xml_xpath_XPathParser__24YyCheckClass$object {
	_jc_gnu_xml_xpath_XPathParser__24YyCheckClass$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_xpath_XPathParser__24YyCheckClass$vtype	*vtype;
	_jc_gnu_xml_xpath_XPathParser__24YyCheckClass$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_xpath_XPathParser__24YyCheckClass$vtype _jc_gnu_xml_xpath_XPathParser__24YyCheckClass$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_xpath_XPathParser__24YyCheckClass, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_xpath_XPathParser__24YyCheckClass$class_object;

#endif	/* _JC_gnu_xml_xpath_XPathParser__24YyCheckClass_H_ */

==> jc-1.4.5.tar.gz: gnu/xml/xpath/XPathParser__24YyCheckClass.h <==
// public final class gnu.xml.xpath.XPathParser$YyCheckClass

// class file dependencies
// @dep_class 4d15a1359e629c72 gnu_xml_xpath_XPathParser__24YyCheckClass
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_xpath_XPathParser__24YyCheckClass_H_
#define _JC_gnu_xml_xpath_XPathParser__24YyCheckClass_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyCheckClass$sub_refs	_jc_gnu_xml_xpath_XPathParser__24YyCheckClass$sub_refs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyCheckClass$sub_nonrefs	_jc_gnu_xml_xpath_XPathParser__24YyCheckClass$sub_nonrefs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyCheckClass$refs	_jc_gnu_xml_xpath_XPathParser__24YyCheckClass$refs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyCheckClass$nonrefs	_jc_gnu_xml_xpath_XPathParser__24YyCheckClass$nonrefs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyCheckClass$object	_jc_gnu_xml_xpath_XPathParser__24YyCheckClass$object;

typedef struct _jc_gnu_xml_xpath_XPathParser__24YyCheckClass$fields_struct	_jc_gnu_xml_xpath_XPathParser__24YyCheckClass$fields_struct;
typedef const struct _jc_gnu_xml_xpath_XPathParser__24YyCheckClass$vmethods	_jc_gnu_xml_xpath_XPathParser__24YyCheckClass$vmethods;
typedef const struct _jc_gnu_xml_xpath_XPathParser__24YyCheckClass$vtable	_jc_gnu_xml_xpath_XPathParser__24YyCheckClass$vtable;
typedef const struct _jc_gnu_xml_xpath_XPathParser__24YyCheckClass$vtype	_jc_gnu_xml_xpath_XPathParser__24YyCheckClass$vtype;

// Class fields structure
struct _jc_gnu_xml_xpath_XPathParser__24YyCheckClass$fields_struct {
	_jc_short_array	*yyCheck;
};
extern _jc_gnu_xml_xpath_XPathParser__24YyCheckClass$fields_struct _jc_gnu_xml_xpath_XPathParser__24YyCheckClass$class_fields;

// Constructors
extern void _jc_gnu_xml_xpath_XPathParser__24YyCheckClass$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_xml_xpath_XPathParser__24YyCheckClass$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_gnu_xml_xpath_XPathParser__24YyCheckClass$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_xml_xpath_XPathParser__24YyCheckClass$vmethods {
};

// Vtable
struct _jc_gnu_xml_xpath_XPathParser__24YyCheckClass$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_xpath_XPathParser__24YyCheckClass$vmethods	gnu_xml_xpath_XPathParser__24YyCheckClass;
};

// Vtype
struct _jc_gnu_xml_xpath_XPathParser__24YyCheckClass$vtype {
	_jc_type			type;
	_jc_gnu_xml_xpath_XPathParser__24YyCheckClass$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_xpath_XPathParser__24YyCheckClass$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_xpath_XPathParser__24YyCheckClass$refs {
    _jc_gnu_xml_xpath_XPathParser__24YyCheckClass$sub_refs	gnu_xml_xpath_XPathParser__24YyCheckClass;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_xpath_XPathParser__24YyCheckClass$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_xpath_XPathParser__24YyCheckClass$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_xpath_XPathParser__24YyCheckClass$sub_nonrefs	gnu_xml_xpath_XPathParser__24YyCheckClass;
};

// Object instance structure
struct _jc_gnu_xml_xpath_XPathParser__24YyCheckClass$object {
	_jc_gnu_xml_xpath_XPathParser__24YyCheckClass$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_xpath_XPathParser__24YyCheckClass$vtype	*vtype;
	_jc_gnu_xml_xpath_XPathParser__24YyCheckClass$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_xpath_XPathParser__24YyCheckClass$vtype _jc_gnu_xml_xpath_XPathParser__24YyCheckClass$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_xpath_XPathParser__24YyCheckClass, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_xpath_XPathParser__24YyCheckClass$class_object;

#endif	/* _JC_gnu_xml_xpath_XPathParser__24YyCheckClass_H_ */
